@@ -26,7 +26,7 @@ from resource_man.importlib_interface import \
 from resource_man.interface import \
     ResourceNotAvailable, Resource, ResourceManagerInterface, ResourceManager, \
     get_global_manager, set_global_manager, temp_manager, add_manager, remove_manager, \
-    clear, register, register_data, register_directory, unregister, has_resource, \
+    clear, register_resource, register, register_data, register_directory, unregister, has_resource, \
     get_resources, get_resource, get_binary, get_text, registered_datas, \
     MISSING
 
@@ -53,7 +53,7 @@ __all__ = [
 
     'ResourceNotAvailable', 'Resource', 'ResourceManagerInterface', 'ResourceManager',
     'get_global_manager', 'set_global_manager', 'temp_manager', 'add_manager', 'remove_manager',
-    'clear', 'register', 'register_data', 'register_directory', 'unregister',
+    'clear', 'register_resource', 'register', 'register_data', 'register_directory', 'unregister',
     'has_resource', 'get_resources', 'get_resource', 'get_binary', 'get_text', 'registered_datas',
     'MISSING',
     '__version__'
@@ -537,7 +537,7 @@ def compile_qrc(filename="resource_man_compiled_resources.qrc", output=None, rcc
         if success and is_py and use_qtpy:
             compiled_py_to_qtpy(output)
 
-        return success
+        return output
 
 
 def compiled_py_to_qtpy(filename):
